<template>
  <j-modal :title="title" :width="1300" :visible="visible" :confirmLoading="confirmLoading" switchFullscreen
           @ok="handleOk" @cancel="handleCancel" cancelText="关闭">
    <a-spin :spinning="confirmLoading">
      <a-form-model ref="form" :model="model" :rules="validatorRules" :labelCol="labelCol" :wrapperCol="wrapperCol">
        <a-row>
          <a-col :span="8">
            <a-form-model-item label="工单号">
              <a-input placeholder="选择设备后自动带出" disabled v-model="model.orderId"/>
            </a-form-model-item>
          </a-col>
          <a-col :span="8">
            <a-form-model-item label="变更单号">
              <a-input placeholder="系统自动生成" disabled v-model="model.changeOrderNum"/>
            </a-form-model-item>
          </a-col>
          <a-col :span="8">
            <a-form-model-item prop="equipmentId" label="统一编码">
              <maintenance-equipment-select placeholder="请输入统一编码或名称搜索" v-model="model.equipmentId"
                                            maintenanceCategory="THIRD_MAINTENANCE" @autocompleteForm="autocompleteForm"/>
            </a-form-model-item>
          </a-col>
          <a-col :span="8">
            <a-form-model-item prop="deferredMaintenanceDate" label="延迟保养日期">
              <a-date-picker v-model="model.deferredMaintenanceDate" value-format="YYYY-MM-DD" style="width: 100%"/>
            </a-form-model-item>
          </a-col>
          <a-col :span="8">
            <a-form-model-item prop="applyCategory" label="申请类型">
              <j-dict-select-tag v-model="model.applyCategory" placeholder="请选择申请类型"
                                 dict-code="third_maintenance_change_category"/>
            </a-form-model-item>
          </a-col>
          <a-col :span="8">
            <a-form-model-item prop="applyReasonType" label="变更原因类型">
              <j-dict-select-tag v-model="model.applyReasonType" placeholder="请选择变更原因类型"
                                 dict-code="third_maintenance_change_reason"/>
            </a-form-model-item>
          </a-col>
          <a-col :span="24">
            <a-form-model-item label="变更原因" :labelCol="{span:2}" :wrapperCol="{span:21}">
              <a-textarea v-model="model.applyReason" placeholder="请输入变更原因"/>
            </a-form-model-item>
          </a-col>
          <a-col :span="24">
            <a-form-model-item label="备注" :labelCol="{span:2}" :wrapperCol="{span:21}">
              <a-textarea v-model="model.remark" placeholder="请输入备注"/>
            </a-form-model-item>
          </a-col>
        </a-row>
      </a-form-model>
    </a-spin>
  </j-modal>
</template>

<script>
import { postAction } from '@/api/manage'
import MaintenanceEquipmentSelect from '@views/eam/equipment/modules/MaintenanceEquipmentSelect.vue'

export default {
  name: 'EamThirdMaintenanceChangeModal',
  components: {
    MaintenanceEquipmentSelect

  },
  data() {
    return {
      title: '操作',
      visible: false,
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 6 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 15 }
      },
      confirmLoading: false,
      validatorRules: {
        deferredMaintenanceDate: [{ required: true, message: '请选择日期', trigger: 'change' }],
        applyCategory: [{ required: true, message: '请选择申请类型', trigger: 'change' }],
        applyReasonType: [{ required: true, message: '请选择变更原因', trigger: 'change' }],
      },
      url: {
        add: '/eam/eamThirdMaintenanceChange/add',
        edit: '/eam/eamThirdMaintenanceChange/edit'
      }
    }
  },
  methods: {
    add({ id, equipmentId }) {
      this.model = Object.assign({ orderId: id, equipmentId })
      this.visible = true
    },

    edit(record) {
      this.model = Object.assign({}, record)
      this.visible = true
    },

    handleOk() {
      const that = this
      // 触发表单验证
      this.$refs.form.validate(valid => {
        if (valid) {
          that.confirmLoading = true

          let httpUrl
          if (!that.model.id) {
            httpUrl = that.url.add
          } else {
            httpUrl = that.url.edit
          }

          postAction(httpUrl, that.model)
            .then((res) => {
              if (res.success) {
                that.$notification.success({
                  message: '消息',
                  description: res.message
                })
                if (!that.model.id) {
                  that.$router.push('/eam/maintenance/EamThirdMaintenanceChangeList')
                  return
                }
                that.close()
                that.$emit('ok')
              } else {
                that.$notification.warning({
                  message: '消息',
                  description: res.message
                })
              }
            })
            .finally(() => {
              that.confirmLoading = false
            })
        } else {
          return false
        }
      })
    },

    handleCancel() {
      this.close()
    },

    close() {
      this.$emit('close')
      this.visible = false
      this.$refs.form.clearValidate()
    }
  }
}
</script>